//
//  ActivityRecognitionManager.swift
//  activity_rec_flutter
//
//  Created by WOO JIN HWANG on 2021/04/23.
//

import CoreMotion
import Foundation
import SQLite3

typealias ActivityDataHandler = (ActivityData) -> Void

class ActivityRecognitionManager {
  private let motionActivityManager = CMMotionActivityManager()
  private var isRunningService = false

  public func startService(handler: @escaping ActivityDataHandler) {
    if (isRunningService) {
      NSLog("ActivityRecognitionManager The activity recognition service has already started.")
      stopService()
    }

    motionActivityManager.startActivityUpdates(to: .main) { (activity) in
      guard let activity = activity else { return }

      let actData = ActivityData(from: activity)
      let currentTime = String(Date().timeIntervalSince1970 * 1000)

      print("ActivityRecognitionManager activity type: \(actData.type), confidence: \(actData.confidence)")

      DatabaseManager.shared.insertActivityData(type: actData.type, confidence: actData.confidence)

      handler(ActivityData(from: activity))
    }
    isRunningService = true
  }
  
  public func stopService() {
    motionActivityManager.stopActivityUpdates()
    isRunningService = false
  }
}
